@@ -53,7 +53,7 @@ class PGG_diffusion:
         self._nb_simulation_step = int(nb_simulation_step)
         self._nb_coop = collections.deque(maxlen=maxlen_queue)
         self._nb_def = collections.deque(maxlen=maxlen_queue)
-        self._infected_node = [RD.randint(0,self._nb_node) for x in xrange(self._nb_seeder)]
+        self._infected_node = [RD.randint(0,self._nb_node-1) for x in xrange(self._nb_seeder)]
         self._simulation_time = 0
         self.reset_send_update()
         for nd in self._G.nodes_iter():
@@ -200,7 +200,6 @@ class PGG_diffusion:
     def set_seeder(self, seeder):
         self._infected_node = seeder
 
-
     def set_nodes_states(self, nodes_states):
         for (key, val) in nodes_states.iteritems():
             self._G.node[key]['state'] = val
